# discord-py-buttons is now discord-message-components

This package has been renamed. Use `pip install discord-message-components` instead.

New package: https://pypi.org/project/discord-message-components/
